using System;
using System.IO;
using System.Text;
using System.Xml;
using System.Xml.Xsl;
using System.Xml.XPath;
using Kosmaczewski.Oruga;
using Kosmaczewski.Oruga.XslFo;

namespace Kosmaczewski.Oruga.Html
{
	/// <summary>
	/// HtmlSerializer is an ISerializer that does an XSL transformation on an XslFoDocument instance to
	/// produce an HTML document that can be written to a generic Stream.
	/// </summary>
	public class HtmlSerializer : ISerializer
	{
		private XslFoDocument doc;

		/// <summary>
		/// Constructor.
		/// </summary>
		public HtmlSerializer()
		{
		}

		#region ISerializer Members

		/// <summary>
		/// XslFoDocument source used for the transformation.
		/// </summary>
		public XslFoDocument Source
		{
			get
			{
				return this.doc;
			}
		
			set
			{
				this.doc = value;
			}
		}

		/// <summary>
		/// Writes the result of the transformation to the provided Stream
		/// </summary>
		/// <param name="stream">System.IO.Stream instance that will be used 
		/// to write the result of the transformation</param>
		/// <remarks>This method, when compiled, throws an "Obsolete" warning.</remarks>
		public void Write(Stream stream)
		{
			XslTransform xslt = new XslTransform();
			xslt.Load(Config.XslDir + @"\fo2html.xsl");
			XPathNavigator navigator = this.doc.GetNavigator();
			xslt.Transform(navigator, null, stream);
		}

		#endregion
	}
}
