using System;

namespace Kosmaczewski.Oruga.Rtf
{
	/// <summary>
	/// Different types of tokens commonly found in an RTF stream.
	/// </summary>
	internal enum RtfTokenType
	{
		/// <summary>
		/// Represents a "}" character.
		/// </summary>
		BlockCloser,

		/// <summary>
		/// Represents a "{" character.
		/// </summary>
		BlockOpener,

		/// <summary>
		/// Represents an RTF command, that matches the following regular expression:
		/// /\\([a-z]|\*|\~|\_|\-)+(-?[0-9]+)? ?/. In short, a command starts with a
		/// backslash and letters, then possibly followed by some numbers, and finally
		/// an optional space at the end.
		/// </summary>
		Command,

		/// <summary>
		/// An escape token represents a character not found in the current file encoding schema.
		/// It appears in an RTF stream as "\'ea", where "ea" is the hexadecimal index of 
		/// the escaped character.
		/// </summary>
		Escape,

		/// <summary>
		/// Explicitly indicates the point where a word can be broken by the word processor
		/// (if Hyphenation is available and active). In RTF this is done with the command "\-".
		/// </summary>
		HyphenationPoint,

		/// <summary>
		/// This appears on screen as a hyphen that can not be broken across lines as a normal hyphen.
		/// In RTF this is done with the command "\_".
		/// </summary>
		NonBreakingHyphen,

		/// <summary>
		/// Equivalent to HTML's "&amp;nbsp;", representing a space that will not be used for 
		/// line breaking by the word processor. In RTF this is done with the command "\~".
		/// </summary>
		NonBreakingSpace,

		/// <summary>
		/// Indicates that the next token is not an RTF standard command, but rather one created
		/// for a specific word processor software. In RTF this is done with the command "\*".
		/// </summary>
		StarConstruct,

		/// <summary>
		/// Represents not only the documents text but also command parameters, such as in
		/// "\f0 Courier New"; in this case, "Courier" and "New" would appear as Text tokens, 
		/// while "\f0" would appear as a Command token.
		/// </summary>
		Text,

		/// <summary>
		/// Represents a block of whitespace, typically characters 
		/// 0x0A (10, line feed), 0x0D (13, carriage return) and 0x20 (32, breaking space)
		/// </summary>
		WhiteSpace
	}
}
