<?xml version="1.0"?>
<!--
    You can redistribute this software and/or modify it under the terms of
    the Infozone Software License version 2 published by the Infozone Group
    (http://www.infozone-group.org).
   
    Copyright (C) @year@ by The Infozone Group. All rights reserved.
   
    $Id: fop2rtf.xsl,v 1.1 2000/08/11 13:07:08 jan Exp $
-->

<!-- 
    Style sheet for transformation of FOP to RTF. This works without an
    XSP-processor, however funcionality is very limited.
    
    At this time, the following elements are converted:
        
        fo:block:
            * bold or italic style
            * serif or sans-serif font (all other fonts are ignored)
            * font size
            * block alignment
        fo:inline:
            * bold or italic style
            * serif of sans-serif font (all other fonts are ignored)
            * font size
            
    All other elements are converted to plain text.        
    
    Be sure that the tags in your FO-File are NOT indented. Otherwise the result 
    will not please you, since all whitespace will be seen in the resulting RTF-file.
 -->


<xsl:stylesheet version="1.0" 
        xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
        xmlns:fo="http://www.w3.org/1999/XSL/Format">

<xsl:output method="text" indent="no" media-type="application/rtf"/> 
<xsl:strip-space elements="*"/>

<!-- 
    Root template.
        * creates Standard-ANSI RTF 
        * uses ANSI-charset 
        * uses ANSI-codepage 1252 (Western European)

    Predefined fonts:
        0 - Sans Serif font (Arial)
        1 - Serif font (Times New Roman)     
        
    Color LUT is built up by interpreting the <color>-tags created by the
    fop2itm.xsl-stylesheet.    
-->
<xsl:template match="fo:root">{\rtf\ansi\ansicpg1252{\fonttbl{{\f0\fswiss\fcharset0\fprq0 Arial;}
{\f1\froman\fcharset0\fprq2 Times New Roman;}}}{\colortbl;}
<xsl:apply-templates/>}</xsl:template>


<!-- BLOCKS **********************************************************************-->
<!--
    Conversion of blocks of plain text.
-->    
<xsl:template match="fo:block">\par\pard{<xsl:variable name="blockalign" select="@text-align"/><xsl:choose>
<xsl:when test='$blockalign="centered" or $blockalign="center"'>\qc </xsl:when>
<xsl:when test='$blockalign="end" or $blockalign="right"'>\qr </xsl:when>
<xsl:otherwise>\ql </xsl:otherwise>
</xsl:choose><xsl:variable name="ffamily" select="@font-family"/><xsl:choose>
<xsl:when test='$ffamily="sans-serif"'>\f0 </xsl:when>
<xsl:when test='$ffamily="serif"'>\f1 </xsl:when>
</xsl:choose><xsl:variable name="fsize" select='substring-before(@font-size,"pt")'/>
<xsl:if test='$fsize!=""'>\fs<xsl:value-of select="$fsize*2"/> </xsl:if>
<xsl:variable name="fontstyle" select="@font-style"/><xsl:choose>
<xsl:when test='$fontstyle="italic"'>\i </xsl:when>
</xsl:choose><xsl:variable name="fontweight" select="@font-weight"/><xsl:choose>
<xsl:when test='$fontweight="bold"'>\b </xsl:when>
</xsl:choose><xsl:variable name="lheight" select='substring-before(@line-height,"pt")'/><xsl:choose>
<xsl:when test='$lheight!=""'>\sb<xsl:value-of select="$lheight*5-$fsize*5"/>
\sa<xsl:value-of select="$lheight*5-$fsize*5"/></xsl:when>
<xsl:otherwise>\sb0\sa0</xsl:otherwise></xsl:choose>
<xsl:apply-templates/>}
</xsl:template>  


<!-- INLINE TEXT **********************************************************************-->
<!-- 
    Conversion of inline text and formatting.
-->
<xsl:template match="fo:inline">{<xsl:variable name="ffamily" select="@font-family"/><xsl:choose>
<xsl:when test='$ffamily="sans-serif"'>\f0 </xsl:when>
<xsl:when test='$ffamily="serif"'>\f1 </xsl:when>
</xsl:choose><xsl:variable name="fsize" select='substring-before(@font-size,"pt")'/>
<xsl:if test='$fsize!=""'>\fs<xsl:value-of select="$fsize*2"/> </xsl:if>
<xsl:variable name="fontstyle" select="@font-style"/><xsl:choose>
<xsl:when test='$fontstyle="italic"'>\i </xsl:when>
</xsl:choose><xsl:variable name="fontweight" select="@font-weight"/><xsl:choose>
<xsl:when test='$fontweight="bold"'>\b </xsl:when>
</xsl:choose><xsl:apply-templates/>}</xsl:template>  

</xsl:stylesheet>


