using System;
using System.Text;
using System.Xml;

namespace Kosmaczewski.Oruga.XslFo
{
	/// <summary>
	/// This class helps building XslFoDocument instances, made of many fo:block XML elements.
	/// </summary>
	/// <remarks>This class is based in the GOF Builder design pattern.</remarks>
	public class XslFoBuilder
	{
		private XslFoDocument doc = new XslFoDocument();
		private XmlElement currentBlock = null;
		private StringBuilder stringBuilder = new StringBuilder();

		/// <summary>
		/// Public constructor.
		/// </summary>
		public XslFoBuilder()
		{
		}

		/// <summary>
		/// Gets the XslFoDocument instance, it its current state.
		/// </summary>
		/// <returns>The XslFoDocument instance that is being built.</returns>
		public XslFoDocument GetXslFoDocument()
		{
			return this.doc;
		}

		/// <summary>
		/// Appends text to the fo:block currently being built.
		/// </summary>
		/// <param name="text">The string to append to the block.</param>
		public void AppendText(string text)
		{
			this.stringBuilder.Append(text);
		}

		/// <summary>
		/// Ends the creation and modification process of the fo:block element 
		/// being built and appends it to the XslFoDocument instance.
		/// </summary>
		public void CloseBlock()
		{
			this.AppendCurrentBlock();
		}

		/// <summary>
		/// Creates an element of the specified type in the XslFoDocument instance.
		/// </summary>
		/// <param name="element">The type of element to create.</param>
		public void CreateElement(XslFoElementTypes element)
		{
			switch (element)
			{
				case XslFoElementTypes.Paragraph:
					this.stringBuilder = new StringBuilder();
					this.currentBlock = this.doc.CreateBlock();
					break;

				default:
					break;
			}
		}

		/// <summary>
		/// Sets a style in the fo:block element currently being built.
		/// </summary>
		/// <param name="style">The type of style to set.</param>
		public void SetStyle(XslFoFontStyleTypes style)
		{
			switch (style)
			{
				case XslFoFontStyleTypes.Plain:
					break;

				case XslFoFontStyleTypes.Bold:
					break;

				default:
					break;
			}
		}

		/// <summary>
		/// Appends the current fo:block to the document being built and sets its contents.
		/// </summary>
		private void AppendCurrentBlock()
		{
			this.currentBlock.InnerText = stringBuilder.ToString();
			this.doc.AppendBlock(this.currentBlock);
		}
	}
}
