using System;

namespace Kosmaczewski.Oruga.XslFo
{
	/// <summary>
	/// Represents the different types of font styles handled by the Oruga module.
	/// </summary>
	/// <remarks>This is an enum type marked with the [FlagsAttribute] attribute, 
	/// and can be used as a bit flag enum</remarks>
	[Flags]
	public enum XslFoFontStyleTypes
	{
		/// <summary>
		/// Specifies that the text is to be shown in bold.
		/// </summary>
		Bold,

		/// <summary>
		/// Specifies that the text should be aligned to the center of its container.
		/// </summary>
		CenterAlign,

		/// <summary>
		/// Specifies that the text is to be shown in italics.
		/// </summary>
		Italic,

		/// <summary>
		/// Specifies that the text should be aligned justified.
		/// </summary>
		Justified,

		/// <summary>
		/// Specifies that the text should be aligned to the left side of its container.
		/// </summary>
		LeftAlign,

		/// <summary>
		/// Specifies that all formatting must be removed.
		/// </summary>
		Plain,

		/// <summary>
		/// Specifies that the text should be aligned to the right side of its container.
		/// </summary>
		RightAlign,

		/// <summary>
		/// Specifies that the text is to be shown underlined.
		/// </summary>
		Underlined
	}
}
