#!/usr/bin/perl
require 5;
use strict;
use warnings;
# (Run under a sane version of Perl, with optimal error-checking)

my $dir = $ARGV[0] || '.';
 # If there's no command line argument, then list the
 # contents of the current directory

if($dir eq '.' or $dir eq './') {
  use Cwd; # load the getcwd function's library
  $dir = getcwd();
  # So we can show the full path, instead of just "."
}

# Abort unless we're looking at a real live directory!
die "$dir isn't an existing readable directory"
 unless -e $dir and -d _ and -r _;

# Call our routines to do all the work, then quit:
rtf_start( $dir );
rtfdir( $dir );
rtf_end( $dir );
exit;

#----------------------------------------------------------------
# Three utility routines:

sub in { int(1440 * $_[0]) }  #      inches -> twips

sub cm { int( 567 * $_[0]) }  # centimeters -> twips

sub esc {   # return the given string, escaped as good RTF
  my $in = $_[0];
  $in =~ s{([^-"'?,\$\._a-zA-Z0-9 ])}
          {sprintf("\\'%02x",ord($1))}eg;
   # Actually escapes much more than is necessary, but
   # doesn't handle Unicode -- see Appendix A.
  return $in;
}
#----------------------------------------------------------------

# Declare three global variables for storing file data:
my( @Items, %Size_of, %Time_of );

sub rtfdir {        # do the main work of the program
  my $dir = $_[0];
  scan_dir($dir);  # get the data

  print '{\pard\sa200\qc \fs50\b\i ', esc($dir), ' \par}', "\n\n";
   # page heading: the directory name

  file_row($_, $Size_of{$_}, $Time_of{$_} ) foreach @Items;
   # a row for every file
   
  print '{\pard\sb1440\sa1440\fs28\b\i [Empty!]}' unless @Items;
  
  return;
}

#----------------------------------------------------------------

sub scan_dir {
  #  Gather the data for the files
  #   (this is used by the rtfdir function )
  # It's Just some dull filesystem functions here.
  #
  my $dir = $_[0];
  opendir(IN, $dir) or die "Can't opendir $dir: $!";
  my( $item, $full_path );

  while(defined( $item = readdir(IN) )) {
    next if $item eq '.' or $item eq '..';
    push @Items, $item;
    ( $Size_of{$item}, $Time_of{$item} ) = (-1,-1);

    my $full_path = "$dir/$item";
    ( $Size_of{$item}, $Time_of{$item} ) = ( stat($full_path) )[7,9]
     if -f $full_path;
  }

  closedir(IN);
  @Items = sort by_name @Items;
    # You can change "by_name" to "by_time" or "by_size"
  return;
}

# three ways to sort:
sub by_name { use locale; uc($a) cmp uc($b) } 
sub by_time { $Time_of{$a} <=> $Time_of{$b} }
sub by_size { $Size_of{$a} <=> $Size_of{$b} }

#-----------------------------------------------------------------

sub file_row {
  # Generate a table row for a file+size+time
  #  (used by the rtfdir function)
  
  my($name, $size, $time) = @_;
  my $name_format = '';
  if($size == -1) { # Our flag for a directory
    $name_format = '\b '; # make it bold
    $time = '';
    $size = '';

  } else { # It's a file...
    $time = format_date($time);
    1 while $size =~ s/(\d)(\d\d\d(,|$))/$1,$2/
     # Add commas to the size: 12345 => "12,345"
  }
  
  print '\trowd\trgaph90'; # Start the RTF row declaration
  my $borders = join "", map '\clbrdr' . $_ . '\brdrw15\brdrs',
    qw(t b l r); # turn on these borders (top bottom left right)
  
  print $borders, '\cellx', $_, "\n"
    for in(.85), in(4.25), in(5.75);   # declare the right ends
      # change these numbers as you like
  
  print    # emit the real cells and their content now:
   '\pard\intbl\qr{\fs18\f1\b ',  esc($size) ,'}\cell ',
    # right-align, 9pt Courier bold
   '\ql{\f2 ', $name_format, esc($name), '}\cell ',
    # left-align Times Roman
   '\qc{\fs18 ', esc($time), '}\cell ',
    # centered 9pt Arial
   '\row', "\n\n"
  ;

  return;
}

#------------------------------------------------------------

sub rtf_start {
  my $dir = $_[0];
  print <<'END_RTF_START';
{\rtf1\ansi\deff0
{\fonttbl {\f0\fswiss Arial;}{\f1\fmodern Courier New;}
{\f2\froman Times;}}
\deflang1024\widowctrl\plain\fs24\noproof

END_RTF_START

  # Page header mentioning the path and time:
  print '{\header \pard\qr\plain\f0\fs18\i\noproof ',
    esc($dir . ' ' . format_date(time)),   
    ' - p\chpgn\par}', "\n\n";
  return;
}

sub rtf_end {
  my $dir = $_[0];
  print "\n}\n";
  return;
}


sub format_date {
  my $time = $_[0];
  my($Y,$M,$D,$h,$m) = ( localtime( $time ) )[ 5,4,3,2,1 ];
  return sprintf "%04d-%02d-%02d %02d:%02d", $Y+1900, $M+1, $D, $h,$m;
}

__END__

