@rem = '--*-Perl-*--
@echo off
if "%OS%" == "Windows_NT" goto WinNT
perl -x -S "%0" %1 %2 %3 %4 %5 %6 %7 %8 %9
goto endofperl
:WinNT
perl -x -S "%0" %*
if NOT "%COMSPEC%" == "%SystemRoot%\system32\cmd.exe" goto endofperl
if %errorlevel% == 9009 echo You do not have Perl in your PATH.
if errorlevel 1 goto script_failed_so_exit_with_non_zero_val 2>nul
goto endofperl
@rem ';
#!perl
shift @rem;
#--------------------------------------------------------------------------
# This is a sprawling hack of a program that helps in analyzing RTF source.
# It reads an RTF file, and then spits out a new RTF document that is a
# syntax-indented parse-tree of the original document.
#
# At the end of this program is a long data table that maps RTF command
# names to a short summary of what they mean.  I've tried to make this
# list complete and accurate, but I can't swear it is.
#
# To use this program under Unix, rename this to "rtf2rtf", delete everything
# before the "#!perl" line, and "chmod u+x rtf2rtf".
#
# This program is distributed in the hope that it will be useful, but
# without any warranty; without even the implied warranty of merchantability
# or fitness for a particular purpose.  But let me know if it gives you
# any trouble, okay?
#
#   -- Sean M. Burke, sburke@cpan.org, July 2003

die "Usage:\n$0 infiles\n" unless @ARGV;

use strict;
my $indent = 400;
my $Explain =
 '{\field{\*\fldinst{HYPERLINK \\\\l "%s"}}{\fldrslt{\\\'5c%s}}}'
; # set to '' to turn off explaining

my %K;
if($Explain){ m/^(\S+)\s+=\s+(.+)/ and $K{$1} = $2
 # and (length($2) > 40 and print "$_")
 while <DATA> }
foreach my $in (@ARGV) { rtf2rtf($in) }
exit;

#--------------------------------------------------------------------------

my %newline_after;
BEGIN {
  for(qw(

    cell pard par footnote cellx
    trgaph
    sect sectd
    cols
    column
    line
    
    clbrdrt clbrdrl clbrdrb clbrdrr
    
  )){ $newline_after{$_} = "\\line\n" }
}

#--------------------------------------------------------------------------

sub rtf2rtf {

  my $in = $_[0];
  return unless $in;
  
  unless(-e $in) {
    warn "$in doesn't exist.\n";
    return;
  }
  unless(-f $in) {
    warn "$in isn't a file\n";
    return;
  }
  unless(-r $in) {
    warn "$in isn't a file\n";
    return;
  }

  open(IN, "<", $in) or die "Can't read-open $in: $!";
  binmode(IN);

  my $out = $in;
  $out .= ".rtf";

  open(OUT, ">", $out) or die "Can't write-open $out: $!";
  binmode(OUT);

  my $counter = 0;
  my @stack;
  
  my $x;

  print OUT '{\rtf1\ansi\deff0{\fonttbl
{\f0 \fswiss Arial;}{\f1 \froman Times New Roman;}
}
{\colortbl;\red255\green0\blue0;\red0\green0\blue255;}
\deflang1024\plain\noproof\\fs24
{\pard

';

  while(<IN>) {
    while( # Iterate over tokens on each line
     m<
      \G(?:
        ([{}])  # \1
        |
        (?: \\
            ( (?:
                clFitText | clftsWidth | clNoWrap | clwWidth
                | tdfrmtxtBottom | tdfrmtxtLeft | tdfrmtxtRight | tdfrmtxtTop  
                | trwWidthA    | trwWidthB   | trwWidth
                | trftsWidthA  | trftsWidthB | trftsWidth 
                | sectspecifygenN | ApplyBrkRules
                 # The horrible exception list.  Thanks, MS!!!
              )
              | [a-z]+ # normal syntax
            )              # \2: keyword
            (-?\d+)?       # \3: number
            \x20?
        )
        |
        (?: \\ 
          (?:  (?: '([0-9a-fA-F]{2})) # \4: hex escape
                | ([-_|~:*\cm\cj{}])) # \5: magic character
          )
        |
        ([\cm\cj]+) # \6
        |
        ([^\\{}\cm\cj]+)   # \7: unescaped character data
      )
    >sgx) {


      if( defined $1 ) { #~~~~~~~~ open or close ~~~~~~~~~~~~~~~~~~~~~~~~~~
        if($1 eq '{') {
          ++$counter;
          push @stack, $counter;

          print OUT "\n\\par}\n{\\pard\\li",
              (@stack - 1) * $indent,
              " {\\b\\f1\\'7b}{\\i\\f1\\fs20\n ",
              (@stack > 1) ? (
                "{\\fs16\n",
                join('.', @stack[0 .. $#stack-1], '' ),
                '}',
              ) : (),
              $stack[-1],
              "}\\par}\n\n",
              "{\\pard\\li",
              (@stack) * $indent, "\n",
            ;

          #print OUT "{\\b\\f1\\'5c$2$3} \n";

        } else {  # a close-brace
          if(@stack) {
            print OUT "\n\\par}\n{\\pard\\li",
              (@stack - 1) * $indent,
              " {\\f1\\'7d}{\\i\\f1\\fs20\n ",
              (@stack > 1) ? (
                "{\\fs16\n",
                join('.', @stack[0 .. $#stack-1], '' ),
                '}',
              ) : (),
              $stack[-1],
              "}\n\\line\n\n",
            ;
            pop @stack;
          } else {
            print OUT "\n\\par}\n{\\pard {\\f1\\'7d -- UNMATCHED}\\par}{\\pard\n"
              # and no indenting
            ;
          }
        }


      } elsif( defined $2 ) { # a command ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
      
        #print "\n<!-- Left: [", substr($_, pos($_)), "] -->";
        if(defined($3)) {
          if($2 ne 'bin') {
            if($Explain and $K{$2}) {
              print OUT "{\\f1",
                sprintf($Explain, $K{$2} || '??', $2 . $3),
                "}", $newline_after{$2} || ' ', "\n";
            } else {          
              print OUT "{\\f1\\'5c$2$3}", $newline_after{$2} || ' ',"\n";
            }
          } else { # special case: the 'bin' word.
            if($3 < 1) { # sanity

              print OUT "{\\f1\\'5c$2$3}", $newline_after{$2} || ' ',
              "\n";

            } elsif($3 < (length $_ - pos($_))) {  # all here
              print OUT "{\\f1\\'5c$2$3}{\\i ...and $3 bytes...}\\line\n";
              pos($_) += $3; # skip over that stuff;

            } else {
              print OUT "{\\f1\\'5c$2$3}{\\i ...and $3 bytes...}\\line\n";

              my $l = $3 - length( substr($_,pos($_), $3) );
              $_ = ''; # clear buffer
              my $b;
              while($l > 0 and !eof) {
                $l -= read(STDIN, $b, ($l > 512) ? 512 : $l);
                  # Decent block size, I guess.
              }
            }
          }
        } else { # parameterless command
          if($Explain and $K{$2}) {
            print OUT "{\\f1",
             sprintf($Explain, $K{$2} || '??', $2),
             "}", $newline_after{$2} || ' ', "\n";
          } else {          
            print OUT "{\\f1\\'5c$2}", $newline_after{$2} || ' ', "\n";
          }
        }
      
      
      } elsif( defined $4 ) { # hex escape #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
        print OUT "{\\f1\\'5c$4}\n";
      } elsif( defined $5 ) {
        # ([-_|~:*\cm\cj{}]) )    # \5: magic character of some sort
        if($5 eq '*')      { print OUT "{\\f1\\'5c*}\n" }
        elsif($5 eq "\cm"             # "\" = \'5c, remember
           or $5 eq "\cj") { print OUT "{\\f1\\'5c\\i[NL]}\n" }
        elsif($5 eq '-')   { print OUT "{\\f1\\'5c-}\n"      }
        elsif($5 eq '|')   { print OUT "{\\f1\\'5c|}\n"      }
        elsif($5 eq '_')   { print OUT "{\\f1\\'5c_}\n"      }
        elsif($5 eq ':')   { print OUT "{\\f1\\'5c:}\n"      }
        elsif($5 eq '~')   { print OUT "{\\f1\\'5c\\'7e}\n"  }
        elsif($5 eq '{')   { print OUT "{\\f1\\'5c\\'7b}\n"  }
        elsif($5 eq '}')   { print OUT "{\\f1\\'5c\\'7d}\n"  }
        else               { die "WHAAAAAT <$5>";           }
      } elsif( defined $6 ) {
        # no-op CR or LF
        #print OUT "\\line\n";
      } else {
        #unescaped character data
        print OUT "{\\fs28 $7}\n";;
      }
    }
  }


  if(@stack) {
    print OUT "\n\\par}\n{\\pard\n",  # and no indenting
      "{\\f1 Never closed \\'5c\\'7b",
      (@stack == 1) ? '' : "'s",
      " @stack\\par}{\\pard\n";
  }

  print OUT "\n\n\\line{\\i\\f1 [End of file]}\\par}}";
  
  close(OUT);
  return;
}

__END__
ab = Associated font is bold
absh = height of frame in twips
abslock = Lock anchor
absnoovrlp = Allow overlap with other frames or objects with similar wrapping
absw = width of frame in twips
acaps = Associated font is all capitals
acccomma = Over comma accent
accdot = Over dot accent
accnone = No accent characters (over dot / over comma)
acf = Associated foreground color (the default is 0)
additive = charstyle adds to current formatting
adjustright = Automatically adjust right indent when document grid is defined
adn = Associated font is subscript position in half-points (the default is 6)
aenddoc = Endnotes at end of document
aendnotes = Endnotes at end of section (the default)
aexpnd = Expansion or compression of space between characters in quarter-points; a negative value compresses (the default is 0)
af = Associated font number (the default is 0)
afs = Associated font size in half-points (the default is 24)
aftnbj = Endnotes at bottom of page (bottom justified)
aftncn = Text argument is a notice for continued endnotes
aftnnalc = Endnote numbering-Alphabetic lowercase
aftnnar = Endnote numbering-Arabic numbering
aftnnauc = Endnote numbering-Alphabetic uppercase
aftnnchi = Endnote numbering-Chicago Manual of Style
aftnnchosung = Endnote Korean numbering 1 (*chosung)
aftnncnum = Endnote Circle numbering (*circlenum)
aftnndbar = Endnote double-byte numbering (*dbchar)
aftnndbnum = Endnote kanji numbering without digit character (*dbnum1)
aftnndbnumd = Endnote kanji numbering with digit character (*dbnum2)
aftnndbnumk = Endnote kanji numbering 4 (*dbnum4)
aftnndbnumt = Endnote kanji numbering 3 (*dbnum3)
aftnnganada = Endnote Korean numbering 2 (*ganada)
aftnngbnum = Endnote Chinese numbering 1 (*gb1)
aftnngbnumd = Endnote Chinese numbering 2 (*gb2)
aftnngbnumk = Endnote Chinese numbering 4 (*gb4)
aftnngbnuml = Endnote Chinese numbering 3 (*gb3)
aftnnrlc = Endnote numbering-Roman lowercase (i, ii, iii, ...)
aftnnruc = Endnote numbering-Roman uppercase (I, II, III, ...)
aftnnzodiac = Endnote numbering-Chinese Zodiac numbering 1 (* zodiac1) 
aftnnzodiacd = Endnote numbering-Chinese Zodiac numbering 2 (* zodiac2) 
aftnnzodiacl = Endnote numbering-Chinese Zodiac numbering 3 (* zodiac3)
aftnrestart = Restart endnote numbering each section
aftnrstcont = Continuous endnote numbering (the default)
aftnsep = Text argument separates endnotes from document
aftnsepc = Text argument separates continued endnotes from document
aftnstart = Beginning endnote number (the default is 1)
aftntj = Endnotes beneath text (top justified)
ai = Associated font is italic
alang = Language ID for associated font. (This uses same language ID codes described in standard language table in Character Text section of this Specification.)
allowfieldendsel = Enables selecting entire field with first or last character
allprot = This document has no unprotected areas
alntblind = Don't align table rows independently
alt = The ALT modifier key
animtext = Animated text properties
annotprot = This document is protected for comments (annotations)
ansi = ANSI encoding
ansicpg = Unicode<->ANSI conversions
aoutl = Associated font is outline
ascaps = Associated font is small capitals
ashad = Associated font is shadow
asianbrkrule = Use Asian rules for line breaks with character grid
aspalpha = Auto spacing between DBC and English
aspnum = Auto spacing between DBC and numbers
astrike = Associated font is strikethrough
aul = Associated font is continuous underline. \\aul0 turns off all underlining for alternate font
auld = Associated font is dotted underline
auldb = Associated font is double underline
aulnone = Associated font is no longer underlined
aulw = Associated font is word underline
aup = Superscript position in half-points (the default is 6)
author = Author of document
b = Bold
background = Specifies document background
bdbfhdr = Print body before header/footer
bdrrlswsix = Use Word 6.
bgbdiag = backward diagonal background pattern for paragraph (////)
bgcross = cross background pattern for paragraph
bgdcross = diagonal cross background pattern for paragraph
bgdkbdiag = dark backward diagonal background pattern for paragraph (////)
bgdkcross = dark cross background pattern for paragraph
bgdkdcross = dark diagonal cross background pattern for paragraph
bgdkfdiag = dark forward diagonal background pattern for paragraph (\\\\\\\\)
bgdkhoriz = dark horizontal background pattern for paragraph
bgdkvert = dark vertical background pattern for paragraph
bgfdiag = forward diagonal background pattern for paragraph (\\\\\\\\)
bghoriz = horizontal background pattern for paragraph
bgvert = vertical background pattern for paragraph
bin = The picture is in binary format
binfsxn = printer bin used for first page of section
binsxn = printer bin used for pages of section
bkmkpub = The bookmark identifies a Macintosh Edition Manager publisher object
bliptag = A unique identifier for a picture, where N is a long integer value
blipuid = Precedes a 16-byte identification number for image
blipupi = N represents units per inch on a picture (only certain image types need or output this)
blue = Blue index
bookfold = Book fold printing
bookfoldrev = Reverse book fold printing for bidirectional languages
bookfoldsheets = Sheets per booklet; this should be a multiple of four
box = Border around paragraph (box paragraph)
brdrart = Page border art; N argument is a value from 1 through 165 representing number of border
brdrb = Border bottom
brdrbar = Border outside (right side of odd-numbered pages, left side of even-numbered pages)
brdrbtw = Consecutive paragraphs with identical border formatting are considered part of a single group with border information applying to entire group
brdrcf = color of paragraph border, specified as an index into color table in RTF header
brdrdash = Dashed border
brdrdashd = Dash-dotted border
brdrdashdd = Dash-dot-dotted border
brdrdashdotstr = Striped border
brdrdashsm = Dashed border (small)
brdrdb = Double border
brdrdot = Dotted border
brdremboss = Embossed border
brdrengrave = Engraved border
brdrframe = Border resembles a frame
brdrhair = Hairline border
brdrinset = Inset border
brdrl = Border left
brdrnil = No border specified
brdroutset = Outset border
brdrr = Border right
brdrs = Single-thickness border
brdrsh = Shadowed border
brdrt = Border top
brdrtbl = Table cell has no borders
brdrth = Double-thickness border
brdrthtnlg = Thin-thick border (large)
brdrthtnmg = Thin-thick border (medium)
brdrthtnsg = Thin-thick border (small)
brdrtnthlg = Thick-thin border (large)
brdrtnthmg = Thick-thin border (medium)
brdrtnthsg = Thick-thin border (small)
brdrtnthtnlg = Thin-thick-thin border (large)
brdrtnthtnmg = Thin-thick thin border (medium)
brdrtnthtnsg = Thin-thick thin border (small)
brdrtriple = Triple border
brdrw = width in twips of pen used to draw paragraph border line
brdrwavy = Wavy border
brdrwavydb = Double wavy border
brkfrm = Show hard (manual) page breaks and column breaks in frames
brsp = Space in twips between borders and paragraph
bullet = Bullet character
buptim = Backup time
bxe = Formats page number or cross-reference in bold
caps = All capitals
category = Category of document
cb = Background color (the default is 0)
cbpat = background color of background pattern, specified as an index into document's color table
cchs = Indicates any characters not belonging to default document character set and tells which character set they do belong to
cell = End of table cell
cellx = Defines right boundary of a table cell, including its half of space between cells
cf = Foreground color (the default is 0)
cfpat = fill color, specified as an index into document's color table
cgrid = Character grid
charrsid = RSID value identifying when character formatting was changed
charscalex = Character width scaling
chatn = Annotation reference (annotation text follows in a group)
chbgbdiag = backward diagonal background pattern for text (////)
chbgcross = cross background pattern for text
chbgdcross = diagonal cross background pattern for text
chbgdkbdiag = dark backward diagonal background pattern for text (////)
chbgdkcross = dark cross background pattern for text
chbgdkdcross = dark diagonal cross background pattern for text
chbgdkfdiag = dark forward diagonal background pattern for text (\\\\\\\\)
chbgdkhoriz = dark horizontal background pattern for text
chbgdkvert = dark vertical background pattern for text
chbgfdiag = forward diagonal background pattern for text (\\\\\\\\)
chbghoriz = horizontal background pattern for text
chbgvert = vertical background pattern for text
chbrdr = Character border (border always appears on all sides)
chcbpat = fill color, from color table
chcfpat = background pattern color, from color table
chdate = Current date (as in headers)
chdpa = Current date in abbreviated format
chdpl = Current date in long format
chftn = Automatic footnote reference (footnotes follow in a group)
chftnsep = Anchoring character for footnote separator
chftnsepc = Anchoring character for footnote continuation
chpgn = Current page number (as in headers)
chshdng = Character shading
chtime = Current time (as in headers)
clNoWrap = Do not wrap text for cell
clbgbdiag = backward diagonal background pattern for cell (////)
clbgcross = cross background pattern for cell
clbgdcross = diagonal cross background pattern for cell
clbgdkbdiag = dark backward diagonal background pattern for cell (////)
clbgdkcross = dark cross background pattern for cell
clbgdkdcross = dark diagonal cross background pattern for cell
clbgdkfdiag = dark forward diagonal background pattern for cell (\\\\\\\\)
clbgdkhor = dark horizontal background pattern for cell
clbgdkvert = dark vertical background pattern for cell
clbgfdiag = forward diagonal background pattern for cell (\\\\\\\\)
clbghoriz = horizontal background pattern for cell
clbgvert = vertical background pattern for cell
clbrdrb = Bottom table cell border
clbrdrl = Left table cell border
clbrdrr = Right table cell border
clbrdrt = Top table cell border
clcbpat = background color of background pattern
clcbpatraw = Same as \\clcbpatN for use with table styles
clcfpat = line color of background pattern
clcfpatraw = Same as \\clcfpatN for use with table styles
cldgll = Diagonal line (top right to bottom left)
cldglu = Diagonal line (top left to bottom right)
clftsWidth = Units for \\clwWidthN
clmgf = The first cell in a range of table cells to be merged
clmrg = Contents of table cell are merged with those of preceding cell
clpadb = Bottom cell margin or padding
clpadfb = Units for \\clpadbN
clpadfl = Units for \\clpadlN
clpadfr = Units for \\clpadrN
clpadft = Units for \\clpadtN
clpadl = Left cell margin or padding
clpadr = Right cell margin or padding
clpadt = Top cell margin or padding
clshdng = shading of a table cell in hundredths of a percent
clshdngraw = Same as \\clshdngN for use with table styles
clshdrawnil = No shading specified
cltxbtlr = Text in a cell flows left to right and bottom to top
cltxlrtb = Text in a cell flows from left to right and top to bottom (default)
cltxlrtbv = Text in a cell flows left to right and top to bottom, vertical
cltxtbrl = Text in a cell flows right to left and top to bottom
cltxtbrlv = Text in a cell flows top to bottom and right to left, vertical
clvertalb = Cell bottom align
clvertalc = Cell vertically center align
clvertalt = Cell top align
clvmgf = The first cell in a range of table cells to be vertically merged
clvmrg = Contents of table cell are vertically merged with those of preceding cell
collapsed = Paragraph property active in outline view that specifies that paragraph is collapsed (not viewed)
colno = Column number to be formatted; used to specify formatting for variable-width columns
cols = Number of columns for snaking (the default is 1)
colsr = Space to right of column in twips; used to specify formatting for variable-width columns
colsx = Space between columns in twips (the default is 720)
column = Required column break
colw = Width of column in twips; used to override default constant width setting for variable-width columns
comment = Comments; text is ignored
company = Company of author
crauth = Index into revision table
crdate = Time of revision
creatim = Creation time
cs = Designates character style
ctrl = The CTRL modifier key
cts = Index to style to be used for Click-and-Type (0 is default)
cufi = First-line indent in hundredths of a character unit; overrides \\fiN, although they should both be emitted with equivalent values
culi = Left indent (space before) in character units
curi = Right indent (space after) in character units
cvmme = Treat old-style escaped quotation marks as current style in mail merge data documents
dbch = The text consists of double-byte characters
deff = Declares which font is the default
defformat = Tells RTF reader that document should be saved in RTF format
deflang = Defines default language used in document used with a \\plain control word
deflangfe = Default language ID for Asian/Middle Eastern text in Word
defshp = Indicates that inline picture is a WordArt shape
deftab = Default tab width in twips (the default is 720)
deleted = Marks text as deletion
delrsid = RSID value identifying when text was marked as deleted
dfrauth = Index into revision table
dfrdate = Time of revision
dfrmtxtx = horizontal distance in twips from text on both sides of frame
dfrmtxty = vertical distance in twips from text on both sides of frame
dfrstart = The \\dfrxst array is preceded by \\dfrstart keyword
dfrstop = The \\dfrxst array is terminated by \\dfrstop keyword
dfrxst = Unicode character array with a length byte
dghorigin = Drawing grid horizontal origin in twips (the default is 1,701)
dghshow = Show Nth horizontal drawing gridline (the default is 3)
dghspace = Drawing grid horizontal spacing in twips (the default is 120)
dgmargin = Grid to follow margins
dgsnap = Snap to drawing grid
dgvorigin = Drawing grid vertical origin in twips (the default is 1,984)
dgvshow = Show Nth vertical drawing gridline (the default is 0)
dgvspace = Drawing grid vertical spacing in twips (the default is 120)
dibitmap = Source of picture is a Windows device-independent bitmap
dn = Subscript position in half-points (the default is 6)
dntblnsbdb = Don't balance SBCS/DBCS characters
do = Indicates a drawing object is to be inserted at this point in character stream
dobxcolumn = The drawing object is column relative in x-direction
dobxmargin = The drawing object is margin relative in x-direction
dobxpage = The drawing object is page relative in x-direction
dobymargin = The drawing object is margin relative in y-direction
dobypage = The drawing object is page relative in y-direction
dobypara = The drawing object is paragraph relative in y-direction
doccomm = Comments displayed in Summary Info or Properties dialog box in Word
doctemp = Document is a boilerplate document
doctype = An integer (0-2) that describes document type for AutoFormat.
docvar = A group that defines a document variable name and its value
dodhgt = The drawing object is positioned at following numeric address in z-ordering
dolock = The drawing object's anchor is locked and cannot be moved
donotshowcomments = Don't show comments while reviewing
donotshowinsdel = Don't show insertions and deletions while reviewing
donotshowmarkup = Don't show markup while reviewing
donotshowprops = Don't show formatting while reviewing
dpaendhol = Hollow end arrow (lines only)
dpaendl = Length of end arrow, relative to pen width
dpaendsol = Solid end arrow (lines only)
dpaendw = Width of end arrow, relative to pen width
dparc = Arc drawing primitive
dparcflipx = This indicates that end point of arc is to right of start point
dparcflipy = This indicates that end point of arc is below start point
dpastarthol = Hollow start arrow (lines only)
dpastartl = Length of start arrow, relative to pen width
dpastartsol = Solid start arrow (lines only)
dpastartw = Width of start arrow, relative to pen width
dpcallout = Callout drawing primitive, which consists of both a polyline and a text box
dpcoa = Angle of callout's diagonal line is restricted to one of following
dpcoaccent = Accent bar on callout (vertical bar between polyline and text box)
dpcobestfit = Best fit callout (x-length of each line in callout is similar)
dpcoborder = Visible border on callout text box
dpcodabs = Absolute distance-attached polyline
dpcodbottom = Bottom-attached polyline
dpcodcenter = Center-attached polyline
dpcodescent = Descent of callout
dpcodtop = Top-attached callout
dpcolength = Length of callout
dpcominusx = Text box falls in quadrants II or III relative to polyline origin
dpcominusy = Text box falls in quadrants III or IV relative to polyline origin
dpcooffset = Offset of callout
dpcosmarta = Auto-attached callout
dpcotdouble = Double line callout
dpcotright = Right angle callout
dpcotsingle = Single line callout
dpcottriple = Triple line callout
dpcount = Number of drawing primitives in current group
dpellipse = Ellipse drawing primitive
dpendgroup = End group of drawing primitives
dpfillbgcb = Blue value for background fill color
dpfillbgcg = Green value for background fill color
dpfillbgcr = Red value for background fill color
dpfillbggray = Grayscale value for background fill (in half-percentages)
dpfillbgpal = Render fill background color using PALETTERGB macro instead of RGB macro in Windows
dpfillfgcb = Blue value for foreground fill color
dpfillfgcg = Green value for foreground fill color
dpfillfgcr = Red value for foreground fill color
dpfillfggray = Grayscale value for foreground fill (in half-percentages)
dpfillfgpal = Render fill foreground color using PALETTERGB macro instead of RGB macro in Windows
dpfillpat = Index into a list of fill patterns
dpgroup = Begin group of drawing primitives
dpline = Line drawing primitive
dplinecob = Blue value for line color
dplinecog = Green value for line color
dplinecor = Red value for line color
dplinedado = Dash-dotted line style
dplinedadodo = Dash-dot-dotted line style
dplinedash = Dashed line style
dplinedot = Dotted line style
dplinegray = Grayscale value for line color (in half-percentages)
dplinehollow = Hollow line style (no line color)
dplinepal = Render line color using PALETTERGB macro instead of RGB macro in Windows
dplinesolid = Solid line style
dplinew = Thickness of line (in twips)
dppolycount = Number of vertices in a polyline drawing primitive
dppolygon = Polygon drawing primitive (closed polyline)
dppolyline = Polyline drawing primitive
dpptx = X-coordinate of current vertex (only for lines and polylines)
dppty = Y-coordinate of current vertex (only for lines and polylines)
dprect = Rectangle drawing primitive
dproundr = Rectangle is a round rectangle
dpshadow = Current drawing primitive has a shadow
dpshadx = X-offset of shadow
dpshady = Y-offset of shadow
dptxbtlr = Text box flows from left to right and bottom to top
dptxbx = Text box drawing primitive
dptxbxmar = Internal margin of text box
dptxbxtext = Group that contains text of text box
dptxlrtb = Text box flows from left to right and top to bottom (default)
dptxlrtbv = Text box flows from left to right and top to bottom, vertically
dptxtbrl = Text box flows from right to left and top to bottom
dptxtbrlv = Text box flows from top to bottom and right to left, vertically
dpx = X-offset of drawing primitive from its anchor
dpxsize = X-size of drawing primitive
dpy = Y-offset of drawing primitive from its anchor
dpysize = Y-size of drawing primitive
dropcapli = Number of lines drop cap is to occupy
dropcapt = Type of drop cap
ds = Designates section style
dxfrtext = Distance in twips of a positioned paragraph from text in main text flow in all directions
dy = Day
edmins = Total editing time (in minutes)
embo = Emboss
emdash = Em dash
emfblip = Source of picture is an EMF (enhanced metafile)
emspace = Nonbreaking space equal to width of character m in current font
endash = En dash
enddoc = Footnotes at end of document
endnhere = Endnotes included in section
endnotes = Footnotes at end of section (the default)
enspace = Nonbreaking space equal to width of character n in current font
expnd = Expansion or compression of space between characters in quarter-points; a negative value compresses (the default is 0)
expndtw = Expansion or compression of space between characters in twips; a negative value compresses
expshrtn = Expand character spaces on line-ending with SHIFT+RETURN
f = Font number
faauto = Font alignment default setting for this is Auto.
facenter = Font alignment -  Center
facingp = Facing pages (activates odd/even headers and gutters)
fafixed = Font alignment - Upholding fixed
fahang = Font alignment - Hanging
falt = Indicates alternate font name to use if specified font in font table is not available.
faroman = Font alignment - Roman (default)
favar = Font alignment - Upholding variable
fbias = Used to arbitrate between two fonts when a particular character can exist in either non-Far East or Far East font
fbidi = Arabic, Hebrew, or other bidirectional font
fchars = List of following Kinsoku characters
fcharset = Specifies font's character set
fdecor = Decorative fonts
fet = Footnote/endnote type
ffdefres = Default entry for list field
ffdeftext = Default text for text field (string)
ffentrymcr = Macro to be executed upon entry into this form field (string)
ffexitmcr = Macro to be executed upon exit from this form field (string)
ffformat = Format for text field (string)
ffhaslistbox = 1 if this field has list box attached to it, 0 otherwise
ffhelptext = Help text (string)
ffhps = Check box size (half-point sizes)
ffl = List of text for list field
ffmaxlen = Number of characters for text field
ffname = Form field name (string)
ffownhelp = 1 if there is associated Help text (defined under \\ffhelptext), 0 otherwise
ffownstat = 1 if there is associated status line text (defined under \\ffstattext), 0 otherwise
ffprot = 1 if this field is protected, 0 otherwise
ffrecalc = 1 if field should be calculated on exit, 0 otherwise
ffres = Result field for a form field
ffsize = Type of size selected for check box field
ffstattext = Status line text (string)
fftype = Form field type
fftypetxt = Type of text field
fi = First-line indent (the default is 0)
fid = File ID number
file = Marks beginning of a file group, which lists relevant information about referenced file
filetbl = A list of documents referenced by current document
fittext = Fit text in current group in N twips
flddirty = A formatting change has been made to field result since field was last updated
fldedit = Text has been added to, or removed from, field result since field was last updated
fldinst = Field instructions
fldlock = Field is locked and cannot be updated
fldpriv = Result is not in a form suitable for display
fldrslt = Most recent calculated result of field
fmodern = Fixed-pitch serif and sans serif fonts
fn = function key where N is function key number
fname = nontagged font name
fnetwork = Network file system
fnil = Unknown or default fonts (the default)
fnonfilesys = Indicates http/odma
footer = Footer on all pages
footerf = Footer on first page only
footerl = Footer on left pages only
footerr = Footer on right pages only
footery = Footer is N twips from bottom of page (the default is 720)
formdisp = This document currently has a forms drop-down box or check box selected
formfield = Group destination keyword indicating start of form field data
formprot = This document is protected for forms
formshade = This document has form field shading on
fosnum = Currently only filled in for paths from Macintosh file system
fprq = Specifies pitch of a font in font table
fracwidth = Uses fractional character widths when printing (QuickDraw only)
frelative = The character position within path (starting at 0) where referenced file's path starts to be relative to path of owning document
frmtxbtlr = Frame box flows left to right and bottom to top
frmtxlrtb = Frame box flows from left to right and top to bottom (default)
frmtxlrtbv = Frame box flows left to right and top to bottom, vertical
frmtxtbrl = Frame box flows right to left and top to bottom
frmtxtbrlv = Frame box flows top to bottom and right to left, vertical
froman = Roman, proportionally spaced serif fonts
fromhtml = Indicates document was originally HTML and may contain encapsulated HTML tags
fromtext = Indicates document was originally plain text
fs = Font size in half-points (the default is 24)
fscript = Script fonts
fswiss = Swiss, proportionally spaced sans serif fonts
ftech = Technical, symbol, and mathematical fonts
ftnbj = Footnotes at bottom of page (bottom justified)
ftncn = Text argument is a notice for continued footnotes
ftnil = Unknown or default font type (the default)
ftnlytwnine = Don't lay out footnotes like Word 6.
ftnnalc = Footnote numbering-Alphabetic lowercase (a, b, c, ...)
ftnnar = Footnote numbering-Arabic numbering (1, 2, 3, ...)
ftnnauc = Footnote numbering-Alphabetic uppercase (A, B, C, ...)
ftnnchi = Footnote numbering-Chicago Manual of Style
ftnnchosung = Footnote Korean numbering 1 (*chosung)
ftnncnum = Footnote Circle numbering (*circlenum)
ftnndbar = Footnote double-byte numbering (*dbchar)
ftnndbnum = Footnote kanji numbering without digit character (*dbnum1)
ftnndbnumd = Footnote kanji numbering with digit character (*dbnum2)
ftnndbnumk = Footnote kanji numbering 4 (*dbnum4)
ftnndbnumt = Footnote kanji numbering 3 (*dbnum3)
ftnnganada = Footnote Korean numbering 2 (*ganada)
ftnngbnum = Footnote Chinese numbering 1 (*gb1)
ftnngbnumd = Footnote Chinese numbering 2 (*gb2)
ftnngbnumk = Footnote Chinese numbering 4 (*gb4)
ftnngbnuml = Footnote Chinese numbering 3 (*gb3)
ftnnrlc = Footnote numbering-Roman lowercase (i, ii, iii, ...)
ftnnruc = Footnote numbering-Roman uppercase (I, II, III, ...)
ftnnzodiac = Footnote numbering-Chinese Zodiac numbering 1 (* zodiac1)
ftnnzodiacd = Footnote numbering-Chinese Zodiac numbering 2 (* zodiac2)
ftnnzodiacl = Footnote numbering-Chinese Zodiac numbering 3 (* zodiac3)
ftnrestart = Footnote numbers restart at each section
ftnrstcont = Continuous footnote numbering (the default)
ftnrstpg = Restart footnote numbering each page
ftnsep = Text argument separates footnotes from document
ftnsepc = Text argument separates continued footnotes from document
ftnstart = Beginning footnote number (the default is 1)
ftntj = Footnotes beneath text (top justified)
fttruetype = TrueType font
fvaliddos = MS-DOS file system
fvalidhpfs = HPFS file system
fvalidmac = Macintosh file system
fvalidntfs = NTFS file system
g = Destination related to character grids
gcw = Grid column width
green = Green index
gridtbl = Destination keyword related to character grids
gutter = Gutter width in twips (the default is 0)
gutterprl = Parallel gutter
guttersxn = width of gutter margin for section in twips
header = Header on all pages
headerf = Header on first page only
headerl = Header on left pages only
headerr = Header on right pages only
headery = Header is N twips from top of page (the default is 720)
hich = The text consists of single-byte high-ANSI (0x80-0xFF) characters
highlight = Highlights specified text
hlinkbase = The base address that is used for path of all relative hyperlinks inserted in document
horzdoc = Horizontal rendering
horzsect = Horizontal rendering
horzvert = Text in group flows in a direction opposite to that of main document (Horizontal in vertical and vertical in horizontal)
hr = Hour
htmautsp = Use HTML paragraph auto spacing
hyphauto = Toggles automatic hyphenation (the default is off)
hyphcaps = Toggles hyphenation of capitalized words (the default is on)
hyphconsec = maximum number of consecutive lines that will be allowed to end in a hyphen. 0 means no limit
hyphhotz = Hyphenation hot zone in twips (the amount of space at right margin in which words are hyphenated)
hyphpar = Toggles automatic hyphenation for paragraph
i = Italic
id = Internal ID number
ilvl = The 0-based level of list to which paragraph belongs
impr = Engrave
insrsid = An RSID is inserted to denote session in which particular text was inserted
intbl = Paragraph is part of a table
irow = row index of this row
irowband = row index of row, adjusted to account for header rows
itap = Paragraph nesting level, where 0 is main document, 1 is a table cell, 2 is a nested table cell, 3 is a doubly nested table cell, and so forth
ixe = Formats page number or cross-reference in italic
jcompress = Compressing justification (default)
jexpand = Expanding justification
jpegblip = Source of picture is a JPEG
jsksu = Indicates that strict Kinsoku set must be used for Japanese; \\jsku should not be present if \\ksulangN is present and language N is Japanese
keep = Keep paragraph intact
keepn = Keep paragraph with next paragraph
kerning = Point size (in half-points) above which to kern character pairs. \\kerning0 turns off kerning
keycode = This group is specified within description of a style in style sheet in RTF header
keywords = Selected keywords for document
ksulang = Indicates what language N customized Kinsoku characters defined in \\fchars and \\lchars destinations belong to
landscape = Landscape format
lang = Applies a language to a character
langfe = Applies a language to a character
langfenp = Applies a language to a character
langnp = Applies a language to a character
lastrow = Output if this is last row in table
lbr = Text wrapping break of type
lchars = List of leading Kinsoku characters
ldblquote = Left double quotation mark
level = outline level of paragraph
levelfollow = Specifies which character follows level text
levelindent = Minimum distance from left indent to start of paragraph text (used for Word 7.
leveljc = 0	Left justified1	Center justified2
leveljcn = 0	Left justified for left-to-right paragraphs and right justified for right-to-left paragraphs1	Center justified2
levellegal = 1 if any list numbers from previous levels should be converted to Arabic numbers; 0 if they should be left with format specified by their own level's definition
levelnfc = Specifies number type for level
levelnfcn = Same as \\levelnfc
levelnorestart = 1 if this level does not restart its count each time a number of a higher level is reached; 0 if this level does restart its count each time a number of a higher level is reached
levelnumbers = The argument for this destination should be a string that gives offsets into \\leveltext of level placeholders
levelold = 1 if this level was converted from Word 6.
levelpicture = Determines which picture bullet from \\listpicture destination should be applied
levelprev = 1 if this level includes text from previous level (used for Word 7.
levelprevspace = 1 if this level includes indentation from previous level (used for Word 7.
levelspace = Minimum distance from right edge of number to start of paragraph text (used for Word 7.
levelstartat = N specifies start-at value for level
leveltext = If list is hybrid, as indicated by \\listhybrid, \\leveltemplateidN keyword will be included, whose argument is a unique level ID that should be randomly generated
li = Left indent (the default is 0)
lin = Left indent for left-to-right paragraphs; right indent for right-to-left paragraphs (the default is 0)
line = Required line break (no paragraph break)
linebetcol = Line between columns
linecont = Line numbers continue from preceding section
linemod = Line-number modulus amount to increase each line number (the default is 1)
lineppage = Line numbers restart on each page
linerestart = Line numbers restart at \\linestarts value
linestart = Beginning line number (the default is 1)
linestarts = Beginning line number (the default is 1)
linex = Distance from line number to left text margin in twips (the default is 360)
linkself = The object is a link to another part of same document
linkstyles = Update document styles automatically based on template
linkval = The name of a bookmark that contains text to display as value of property
lisa = Space after in hundredths of a character unit
lisb = Space before in hundredths of a character unit
listhybrid = Present if list has 9 levels, each of which is equivalent of a simple list
listid = Should exactly match \\listid of one of lists in List table
listname = The argument for \\listname is a string that is name of this list
listoverridecount = Number of list override levels within this list override (1 or 9)
listoverrideformat = Number of list override levels within this list override (should be either 1 or 9)
listoverridestartat = Indicates an override of start-at value
listrestarthdn = 1 if list restarts at each section; 0 if not
listsimple = 1 if list has one level; 0 (default) if list has nine levels
liststyleid = This identifies style of this list from list style definition that has this ID as its \\listid
liststylename = Identifies this list as a list style definition
listtemplateid = Each list should have a unique template ID as well, which also should be randomly generated
listtext = Contains flat text representation of number, including character properties
lnbrkrule = Don't use Word 97 line breaking rules for Asian text
lndscpsxn = Page orientation is in landscape format
lnongrid = Define line based on grid
loch = The text consists of single-byte low-ANSI (0x00-0x7F) characters
lquote = Left single quotation mark
ls = Should exactly match ls for one of list overrides in List Override table
ltrch = The character data following this control word will be treated as a left-to-right run (the default)
ltrdoc = Text in this document will be displayed from left to right unless overridden by a more specific control (the default)
ltrmark = The following characters should be displayed from left to right
ltrpar = Text in this paragraph will be displayed with left-to-right precedence (the default)
ltrrow = Cells in this table row will have left-to-right precedence (the default)
ltrsect = This section will thread columns from left to right (the default)
lytcalctblwd = Don't lay out tables with raw width
lytexcttp = Don't center exact line height lines
lytprtmet = Use printer metrics to lay out document
lyttblrtgr = Don't allow table rows to lay out apart
mac = Apple Macintosh encoding
macpict = Source of picture is QuickDraw
makebackup = Backup copy is made automatically when document is saved
manager = Manager of author
margb = Bottom margin in twips (the default is 1440)
margbsxn = bottom margin of page in twips
margl = Left margin in twips (the default is 1800)
marglsxn = left margin of page in twips
margmirror = Switches margin definitions on left and right pages
margmirsxn = Switches margin definitions on left and right pages
margr = Right margin in twips (the default is 1800)
margrsxn = right margin of page in twips
margt = Top margin in twips (the default is 1440)
margtsxn = top margin of page in twips
min = Minute
mo = Month
msmcap = Small caps like Word 5.x for Macintosh
nestcell = End of nested table cell
nestrow = End of nested table row
nesttableprops = Defines properties of a nested table
nextfile = The argument is name of file to print or index next; it must be enclosed in braces
nobrkwrptbl = Don't break wrapped tables across pages
nocolbal = Don't balance columns
nocompatoptions = Specifies that all compatibility options should be set to default
nocwrap = No character wrapping
noextrasprl = Don't add extra space to line height for showing raised/lowered characters
nofchars = Number of characters including spaces
nofcharsws = Number of characters not including spaces
nofpages = Number of pages
nofwords = Number of words
nolead = No external leading
noline = No line numbering
nolnhtadjtbl = Don't adjust line height in table
nonesttables = Contains text for readers that do not understand nested tables
nonshppict = Specifies that Word 97 through Word 2002 has written a \\pict destination that it will not read on input
nooverflow = No overflow period and comma
noproof = Do not check spelling or grammar for text in group
nosectexpand = Disable character space basement
nosnaplinegrid = Disable snap line to grid
nospaceforul = Don't add space for underline
nosupersub = Turns off superscripting or subscripting
notabind = Don't add automatic tab stop for hanging indent
noultrlspc = Don't underline trailing spaces
nowidctlpar = No widow/orphan control
nowrap = Prevents text from flowing around positioned object
nowwrap = No word wrapping
noxlattoyen = Don't translate backslash to Yen sign
objalias = This subdestination contains alias record of publisher object for Macintosh Edition Manager
objalign = distance in twips from left edge of objects that should be aligned on a tab stop
objattph = Object attachment placeholder
objautlink = An object type of OLE autolink
objclass = The text argument is object class to use for this object; ignore class specified in object data
objcropb = bottom cropping value in twips
objcropl = left cropping value in twips
objcropr = right cropping value in twips
objcropt = top cropping value in twips
objdata = This subdestination contains data for object in appropriate format; OLE objects are in OLESaveToStream format
objemb = An object type of OLE embedded object
objh = original object height in twips, assuming object has a graphical representation
objhtml = An object type of Hypertext Markup Language (HTML) control
objicemb = An object type of MS Word for Macintosh Installable Command (IC) Embedder
objlink = An object type of OLE link
objlock = Locks object from any updates
objname = The text argument is name of this object
objocx = An object type of OLE control
objpub = An object type of Macintosh Edition Manager publisher
objscalex = horizontal scaling percentage
objscaley = vertical scaling percentage
objsect = This subdestination contains section record of publisher object for Macintosh Edition Manager
objsetsize = Forces object server to set object's dimensions to size specified by client
objsub = An object type of Macintosh Edition Manager subscriber
objtime = Lists time that object was last updated
objtransy = distance in twips objects should be moved vertically with respect to baseline
objupdate = Forces an update to object before displaying it
objw = original object width in twips, assuming object has a graphical representation
oldas = Use Word 95 Auto spacing
oldcprops = Old character formatting properties
oldlinewrap = Lines wrap like Word 6.0
oldpprops = Old paragraph formatting properties
oldsprops = Old section formatting properties
oldtprops = Old table formatting properties
operator = Person who last made changes to document
otblrul = Combine table borders as done in Word 5.x for Macintosh
outl = Outline
outlinelevel = Outline level of paragraph
overlay = Text flows underneath frame
page = Required page break
pagebb = Break page before paragraph
panose = a 10-byte Panose 1 number
paperh = Paper height in twips (the default is 15,840)
paperw = Paper width in twips (the default is 12,240)
par = End of paragraph
pararsid = RSID identifying when paragraph formatting was changed
pard = Resets to default paragraph properties
pc = IBM PC code page 437 encoding
pca = IBM PC code page 850 encoding
pgbrdrb = Page border bottom
pgbrdrfoot = Page border surrounds footer
pgbrdrhead = Page border surrounds header
pgbrdrl = Page border left
pgbrdropt = 8	Page border measure from text
pgbrdrr = Page border right
pgbrdrsnap = Align paragraph borders and table edges with page border
pgbrdrt = Page border top
pghsxn = page height in twips
pgnbidia = Page-number format is Abjad Jawaz if language is Arabic and Biblical Standard if language is Hebrew
pgnbidib = Page number format is Alif Ba Tah if language is Arabic and Non-standard Decimal if language is Hebrew
pgnchosung = Korean numbering 1 (* chosung)
pgncnum = Circle numbering (*circlenum)
pgncont = Continuous page numbering (the default)
pgndbnum = Kanji numbering without digit character
pgndbnumd = Kanji numbering with digit character
pgndbnumk = Kanji numbering 4 (*dbnum4)
pgndbnumt = Kanji numbering 3 (*dbnum3)
pgndec = Page-number format is decimal
pgndecd = Double-byte decimal numbering
pgnganada = Korean numbering 2 (*ganada)
pgngbnum = Chinese numbering 1 (*gb1)
pgngbnumd = Chinese numbering 2 (*gb2)
pgngbnumk = Chinese numbering 4 (*gb4)
pgngbnuml = Chinese numbering 3 (*gb3)
pgnhindia = Hindi vowel numeric format
pgnhindib = Hindi consonants
pgnhindic = Hindi digits
pgnhindid = Hindi descriptive (cardinal) text
pgnhn = Indicates which heading level is used to prefix a heading number to page number
pgnhnsc = Colon separator character
pgnhnsh = Hyphen separator character
pgnhnsm = Em dash (-) separator character
pgnhnsn = En dash (-) separator character
pgnhnsp = Period separator character
pgnid = Page number in dashes (Korean)
pgnlcltr = Page-number format is lowercase letter
pgnlcrm = Page-number format is lowercase Roman numeral
pgnrestart = Page numbers restart at \\pgnstarts value
pgnstart = Beginning page number (the default is 1)
pgnstarts = Beginning page number (the default is 1)
pgnthaib = Thai digits
pgnthaic = Thai descriptive
pgnucltr = Page-number format is uppercase letter
pgnucrm = Page-number format is uppercase Roman numeral
pgnvieta = Vietnamese descriptive
pgnx = Page number is N twips from right margin (the default is 720)
pgny = Page number is N twips from top margin (the default is 720)
pgnzodiac = Chinese Zodiac numbering 1 (*zodiac1)
pgnzodiacd = Chinese Zodiac numbering 2 (*zodiac2)
pgnzodiacl = Chinese Zodiac numbering 3 (*zodiac3)
pgwsxn = page width in twips
phcol = Use column as horizontal reference frame
phmrg = Use margin as horizontal reference frame
phnthaia = Thai letters
phpg = Use page as horizontal reference frame
picbmp = Specifies whether a metafile contains a bitmap
picbpp = Specifies bits per pixel in a metafile bitmap
piccropb = Bottom cropping value in twips
piccropl = Left cropping value in twips
piccropr = Right cropping value in twips
piccropt = Top cropping value in twips
pich = yExt field if picture is a Windows metafile; picture height in pixels if picture is a bitmap or from QuickDraw
pichgoal = Desired height of picture in twips
picprop = Indicates there are shape properties applied to an inline picture
picscaled = Scales picture to fit within specified frame
picscalex = Horizontal scaling value
picscaley = Vertical scaling value
picw = xExt field if picture is a Windows metafile; picture width in pixels if picture is a bitmap or from QuickDraw
picwgoal = Desired width of picture in twips
plain = Reset font (character) formatting properties to a default value defined by application
pmmetafile = Source of picture is an OS/2 metafile
pn = Turns on paragraph numbering
pnacross = Number across rows (the default is to number down columns)
pnaiu = 46 phonetic katakana characters in "aiueo" order (\\*aiueo)
pnaiud = 46 phonetic double-byte katakana characters (\\*aiueo\\*dbchar)
pnaiueo = 46 phonetic katakana characters in "aiueo" order (*aiueo)
pnaiueod = 46 phonetic double-byte katakana characters (*aiueo*dbchar)
pnb = Bold numbering
pnbidia = Abjad Jawaz if language is Arabic and Biblical Standard if language is Hebrew
pnbidib = Alif Ba Tah if language is Arabic and Non-standard Decimal if language is Hebrew
pncaps = All caps numbering
pncard = Cardinal numbering (One, Two, Three)
pncf = Foreground color-index into color table (the default is 0)
pnchosung = Korean numbering 2 (*chosung)
pncnum = 20 numbered list in circle (\\*circlenum)
pndbnum = Kanji numbering without digit character (\\*dbnum1)
pndbnumd = Kanji numbering with digit character (*dbnum2)
pndbnumk = Kanji numbering 4 (*dbnum4)
pndbnuml = Kanji numbering 3 (*dbnum3)
pndbnumt = Kanji numbering 3 (*dbnum3)
pndec = Decimal numbering (1, 2, 3)
pndecd = Double-byte decimal numbering (\\*arabic\\*dbchar)
pnf = Font number
pnfs = Font size (in half-points)
pnganada = Korean numbering 1 (*ganada)
pngblip = Source of picture is a PNG
pngbnum = Chinese numbering 1 (*gb1)
pngbnumd = Chinese numbering 2 (*gb2)
pngbnumk = Chinese numbering 4 (*gb4)
pngbnuml = Chinese numbering 3 (*gb3)
pnhang = Paragraph uses a hanging indent
pni = Italic numbering
pnindent = Minimum distance from margin to body text
pniroha = 46 phonetic katakana characters in "iroha" order (\\*iroha)
pnirohad = 46 phonetic double-byte katakana characters (\\*iroha\\*dbchar)
pnlcltr = Lowercase alphabetic numbering (a, b, c)
pnlcrm = Lowercase Roman numbering (i, ii, iii)
pnlvl = Paragraph level, where N is a level from 1 to 9
pnlvlblt = Bulleted paragraph (corresponds to level 11)
pnlvlbody = Simple paragraph numbering (corresponds to level 10)
pnlvlcont = Continue numbering but do not display number ("skip numbering")
pnnumonce = Number each cell only once in a table (the default is to number each paragraph in a table)
pnord = Ordinal numbering (1st, 2nd, 3rd)
pnordt = Ordinal text numbering (First, Second, Third)
pnprev = Used for multilevel lists
pnqc = Centered numbering
pnql = Left-justified numbering
pnqr = Right-justified numbering
pnrauth = Index into revision table
pnrdate = Time of revision
pnrestart = Restart numbering after each section break
pnrnfc = Nine-item array containing number format codes of each level (using same values as \\levelnfc keyword)
pnrnot = Indicates whether paragraph number for current paragraph is marked as "inserted."
pnrpnbr = Nine-item array of actual values of number in each level
pnrrgb = Nine-item array of indices of level place holders in \\pnrxst array
pnrstart = The \\pnrxst, \\pnrrgb, \\pnrpnbr, and \\pnrnfc arrays are each preceded by \\pnrstart keyword, whose argument is 0 through 3, depending on array
pnrstop = The \\pnrxst, \\pnrrgb, \\pnrpnbr, and \\pnrnfc arrays are each terminated by \\pnrstop keyword, whose argument is number of bytes written out in array
pnrxst = The keywords \\pnrxst, \\pnrrgb, \\pnrpnbr, and \\pnrnfc describe "deleted number" text for paragraph number
pnscaps = Small caps numbering
pnseclvl = Used for multilevel lists
pnsp = Distance from number text to body text
pnstart = Start at number
pnstrike = Strikethrough numbering
pntext = This group precedes all numbered/bulleted paragraphs and contains all automatically generated text and formatting
pntxta = Text after
pntxtb = Text before
pnucltr = Uppercase alphabetic numbering (A, B, C)
pnucrm = Uppercase Roman numbering (I, II, III)
pnul = Continuous underline
pnuld = Dotted underline
pnuldash = Dashed underline
pnuldashd = Dash-dotted underline
pnuldashdd = Dash-dot-dotted underline
pnuldb = Double underline
pnulhair = Hairline underline
pnulnone = Turns off underlining
pnulth = Thick underline
pnulw = Word underline
pnulwave = Wave underline
pnzodiac = Chinese Zodiac numbering 1 (*zodiac1)
pnzodiacd = Chinese Zodiac numbering 2 (*zodiac2)
pnzodiacl = Chinese Zodiac numbering 3 (*zodiac3)
posnegx = Same as \\posx but allows arbitrary negative values
posnegy = Same as \\posy but allows arbitrary negative values
posx = Positions frame N twips from left edge of reference frame
posxc = Centers frame horizontally within reference frame
posxi = Positions paragraph horizontally inside reference frame
posxl = Positions paragraph to left within reference frame
posxo = Positions paragraph horizontally outside reference frame
posxr = Positions paragraph to right within reference frame
posy = Positions paragraph N twips from top edge of reference frame
posyb = Positions paragraph at bottom of reference frame
posyc = Centers paragraph vertically within reference frame
posyil = Positions paragraph vertically to be inline
posyin = Positions paragraph vertically inside reference frame
posyout = Positions paragraph vertically outside reference frame
posyt = Positions paragraph at top of reference frame
prcolbl = Print all colors as black
printdata = This document has print form data only on
printim = Last print time
private = Obsolete destination
propname = The name of user-defined property
proptype = Specifies type of property
psover = Prints PostScript over text
psz = Used to differentiate between paper sizes with identical dimensions in  Microsoft Windows NT
pubauto = The publisher object updates all Macintosh Edition Manager subscribers of this object automatically, whenever it is edited
pvmrg = Positions reference frame vertically relative to margin
pvpara = Positions reference frame vertically relative to top left corner of next unframed paragraph in RTF stream
pvpg = Positions reference frame vertically relative to page
pxe = "Yomi" (pronunciation) for index entry
qc = Centered
qd = Distributed
qj = Justified
qk = Percentage of line occupied by Kashida justification (0 - low, 10 - medium, 20 - high)
ql = Left-aligned (the default)
qmspace = One-quarter em space
qr = Right-aligned
qt = For Thai distributed justification
rawclbgbdiag = Same as \\clbgbdiag for use with table styles
rawclbgcross = Same as \\clbgcross for use with table styles
rawclbgdcross = Same as clbgdcross for use with table styles
rawclbgdkbdiag = Same as \\clbgdkbdiag for use with table styles
rawclbgdkcross = Same as \\clbgdkcross for use with table styles
rawclbgdkdcross = Same as \\clbgdkdcross for use with table styles
rawclbgdkfdiag = Same as \\clbgdkfdiag for use with table styles
rawclbgdkhor = Same as \\clbgdkhor for use with table styles
rawclbgdkvert = Same as \\clbgdkvert for use with table styles
rawclbgfdiag = Same as \\clbgfdiag for use with table styles
rawclbghoriz = Same as \\clbghoriz for use with table styles
rawclbgvert = Same as \\clbgvert for use with table styles
rdblquote = Right double quotation mark
red = Red index
rempersonalinfo = This will indicate to emitting program to remove personal information such as author's name as a document property or in a comment
result = The result destination is optional in \\object destination
revauth = Index into revision table
revauthdel = Index into revision table
revbar = Vertical lines mark altered text, based on argument
revdttm = Time of revision
revdttmdel = Time of deletion
revised = Text has been added since revision marking was turned on
revisions = Turns on revision marking
revprop = Argument indicates how revised text will be displayed
revprot = This document is protected for revisions
revtbl = Table of authors of revisions
revtim = Revision time
ri = Right indent (the default is 0)
rin = Right indent for left-to-right paragraphs; left indent for right-to-left paragraphs (the default is 0)
row = End of table row
rquote = Right single quotation mark
rsid = Each time a document is saved a new entry is added to this table, with N being random number assigned to represent unique session
rsidroot = Designates start of document's history (first save)
rsltbmp = Forces result to be a bitmap, if possible
rslthtml = Forces result to be HTML, if possible
rsltmerge = Uses formatting of current result whenever a new result is obtained
rsltpict = Forces result to be a Windows metafile or MacPict image format, if possible
rsltrtf = Forces result to be RTF, if possible
rslttxt = Forces result to be plain text, if possible
rtf = RTF version
rtlch = The character data following this control word will be treated as a right-to-left run
rtldoc = Text in this document will be displayed from right to left unless overridden by a more specific control
rtlgutter = Gutter is positioned on right
rtlmark = The following characters should be displayed from right to left
rtlpar = Text in this paragraph will be displayed with right-to-left precedence
rtlrow = Cells in this table row will have right-to-left precedence
rtlsect = This section will thread columns from right to left
rxe BookmarkName = Text argument is a bookmark for range of page numbers
s = Designates paragraph style
sa = Space after (the default is 0)
saauto = Auto spacing after
saftnnalc = Endnote numbering-Alphabetic lowercase (a, b, c, ...)
saftnnar = Endnote numbering-Arabic numbering (1, 2, 3, ...)
saftnnauc = Endnote numbering-Alphabetic uppercase (A, B, C, ...)
saftnnchi = Endnote numbering-Chicago Manual of Style
saftnnchosung = Endnote Korean numbering 1 (*chosung)
saftnncnum = Endnote Circle numbering (*circlenum)
saftnndbar = Endnote double-byte numbering (*dbchar)
saftnndbnum = Endnote kanji numbering without digit character (*dbnum1)
saftnndbnumd = Endnote kanji numbering with digit character (*dbnum2)
saftnndbnumk = Endnote kanji numbering 4 (*dbnum4)
saftnndbnumt = Endnote kanji numbering 3 (*dbnum3)
saftnnganada = Endnote Korean numbering 2 (*ganada)
saftnngbnum = Endnote Chinese numbering 1 (*gb1)
saftnngbnumd = Endnote Chinese numbering 2 (*gb2)
saftnngbnumk = Endnote Chinese numbering 4 (*gb4)
saftnngbnuml = Endnote Chinese numbering 3 (*gb3)
saftnnrlc = Endnote numbering-Roman lowercase (i, ii, iii, ...)
saftnnruc = Endnote numbering-Roman uppercase (I, II, III, ...)
saftnnzodiac = Endnote numbering-Chinese Zodiac numbering 1 (* zodiac1)
saftnnzodiacd = Endnote numbering-Chinese Zodiac numbering 2 (* zodiac2)
saftnnzodiacl = Endnote numbering-Chinese Zodiac numbering 3 (* zodiac3)
saftnrestart = Restart endnote numbering each section
saftnrstcont = Continuous endnote numbering (the default)
saftnstart = Beginning endnote number (the default is 1)
sautoupd = Automatically update styles
sb = Space before (the default is 0)
sbasedon = Defines number of style on which current style is based (the default is 222-no style)
sbauto = Auto spacing before
sbkcol = Section break starts a new column
sbkeven = Section break starts at an even page
sbknone = No section break
sbkodd = Section break starts at an odd page
sbkpage = Section break starts a new page (the default)
sbys = Side-by-side paragraphs
scaps = Small capitals
scompose = Style is e-mail compose style
sec = Seconds
sect = End of section and paragraph
sectd = Reset to default section properties
sectdefaultcl = Default state of section
sectexpand = Character space basement (character pitch minus font size) N in device independent units (a device independent unit is 1/294912th of an inch)
sectlinegrid = Line grid, where N is line pitch in 20ths of a point
sectnum = Current section number (as in headers)
sectrsid = RSID identifying when section formatting was changed
sectspecifycl = Specify number of characters per line only
sectspecifygen = Indicates that text should snap to character grid
sectspecifyl = Specify both number of characters per line and number of lines per page
sectunlocked = This section is unlocked for forms
sftnbj = Footnotes at bottom of page (bottom justified)
sftnnalc = Footnote numbering-Alphabetic lowercase (a, b, c, ...)
sftnnar = Footnote numbering-Arabic numbering (1, 2, 3, ...)
sftnnauc = Footnote numbering-Alphabetic uppercase (A, B, C, ...)
sftnnchi = Footnote numbering-Chicago Manual of Style
sftnnchosung = Footnote Korean numbering 1 (*chosung)
sftnncnum = Footnote Circle numbering (*circlenum)
sftnndbar = Footnote double-byte numbering (*dbchar)
sftnndbnum = Footnote kanji numbering without digit character (*dbnum1)
sftnndbnumd = Footnote kanji numbering with digit character (*dbnum2)
sftnndbnumk = Footnote kanji numbering 4 (*dbnum4)
sftnndbnumt = Footnote kanji numbering 3 (*dbnum3)
sftnnganada = Footnote Korean numbering 2 (*ganada)
sftnngbnum = Footnote Chinese numbering 1 (*gb1)
sftnngbnumd = Footnote Chinese numbering 2 (*gb2)
sftnngbnumk = Footnote Chinese numbering 4 (*gb4)
sftnngbnuml = Footnote Chinese numbering 3 (*gb3)
sftnnrlc = Footnote numbering-Roman lowercase (i, ii, iii, ...)
sftnnruc = Footnote numbering-Roman uppercase (I, II, III, ...)
sftnnzodiac = Footnote numbering-Chinese Zodiac numbering 1 (* zodiac1)
sftnnzodiacd = Footnote numbering-Chinese Zodiac numbering 2 (* zodiac2)
sftnnzodiacl = Footnote numbering-Chinese Zodiac numbering 3 (* zodiac3)
sftnrestart = Footnote numbers restart at each section
sftnrstcont = Continuous footnote numbering (the default)
sftnrstpg = Restart footnote numbering each page
sftnstart = Beginning footnote number (the default is 1)
sftntj = Footnotes beneath text (top justified)
shad = Shadow
shading = shading of paragraph in hundredths of a percent
shidden = Style does not appear in Styles drop-down list in Style dialog box  (on Format menu, click Styles)
shift = The SHIFT modifier key
shpbottom = Specifies position of shape from bottom of anchor
shpbxcolumn = The shape is positioned relative to column in x (horizontal) direction
shpbxignore = Ignore \\shpbxpage, \\shpbxmargin, and \\shpbxcolumn, in favor of \\posrelh
shpbxmargin = The shape is positioned relative to margin in x (horizontal) direction
shpbxpage = The shape is positioned relative to page in x (horizontal) direction
shpbyignore = Ignore \\shpbypage, \\shpbymargin, and \\shpbxpara, in favor of \\posrelh
shpbymargin = The shape is positioned relative to margin in y (vertical) direction
shpbypage = The shape is positioned relative to page in y (vertical) direction
shpbypara = The shape is positioned relative to paragraph in y (vertical) direction
shpfblwtxt = Describes relative z-ordering
shpfhdr = Set to 0 if shape is in main document
shpgrp = group shape
shpleft = Specifies position of shape from left of anchor
shplid = A number that is unique to each shape
shplockanchor = Lock anchor for a shape
shppict = Word 97 through Word 2002 picture
shpright = Specifies position of shape from right of anchor
shprslt = This is where Word 6.
shptop = Specifies position of shape from top of anchor
shptxt = Text for a shape
shpwr = Describes type of wrap for shape
shpwrk = Wrap on side (for types 2 and 4 for \\shpwrN )
shpz = Describes z-order of shape
sl = Space between lines
slmult = Line spacing multiple
snapgridtocell = Snap text to grid inside table with inline objects
snext = Defines next style associated with current style; if omitted, next style is current style
softcol = Nonrequired column break
softlheight = Nonrequired line height
softline = Nonrequired line break
softpage = Nonrequired page break
spersonal = Style is a personal e-mail style
splytwnine = Don't lay out AutoShapes like Word 97
sprsbsp = Suppress extra line spacing at bottom of page
sprslnsp = Suppress extra line spacing like WordPerfect version 5.x
sprsspbf = Suppress space before paragraph property after hard page or column break
sprstsm = Does nothing
sprstsp = Suppress extra line spacing at top of page
spv = Style separator feature that causes paragraph mark to not appear even in ShowAll
sreply = Style is e-mail reply style
ssemihidden = Style does not appear in drop-down menus
staticval = The value of property
stextflow = Section property for specifying text flow
strike = Strikethrough
striked = Double strikethrough
stshfbi = Defines what font should be used by default in style sheet for Complex Scripts (BiDi) characters
stshfdbch = Defines what font should be used by default in style sheet for Far East characters
stshfhich = Defines what font should be used by default in style sheet for High-ANSI characters
stshfloch = Defines what font should be used by default in style sheet for ACSII characters
styrsid = Tied to rsid table, N is rsid of author who implemented style
sub = Subscripts text and shrinks point size according to font information
subdocument = Indicates that a subdocument in a master document/subdocument relationship should occur here
subfontbysize = Substitute fonts based on size first
subject = Subject of document
super = superscript
swpbdr = maybe swap paragraph borders on odd pages
tab = Tab character
tabsnoovrlp = Do not allow table to overlap with other tables or shapes with similar wrapping not contained within it
taprtl = Indicates that table direction is right-to-left
tb = Bar tab position in twips from left margin
tbllkbestfit = sets table autoformat to apply best fit
tbllkborder = sets table autoformat to format borders
tbllkcolor = sets table autoformat to affect color
tbllkfont = sets table autoformat to affect font
tbllkhdrcols = sets table autoformat to format first (header) column
tbllkhdrrows = sets table autoformat to format first (header) row
tbllklastcol = sets table autoformat to format last column
tbllklastrow = sets table autoformat to format last row
tbllkshading = sets table autoformat to affect shading
tblrsid = RSID identifying when table formatting was changed
tcelld = Sets table cell defaults
tcf = Type of table being compiled
tcl = Level number (the default is 1)
tdfrmtxtBottom = Distance in twips, between bottom of table and surrounding text (the default is 0)
tdfrmtxtLeft = Distance in twips, between left of table and surrounding text (the default is 0)
tdfrmtxtRight = Distance in twips, between right of table and surrounding text (the default is 0)
tdfrmtxtTop = Distance in twips, between top of table and surrounding text (the default is 0)
template = The argument is name of a related template file; it must be enclosed in braces
title = Title of document
titlepg = First page has a special format
tldot = Leader dots
tleq = Leader equal sign
tlhyph = Leader hyphens
tlmdot = Leader middle dots
tlth = Leader thick line
tlul = Leader underline
toplinepunct = Turns on a check box in Paragraph Formatting dialogue box with a setting to allow punctuation at start of line to compress
tphcol = Use column as horizontal reference frame
tphmrg = Use margin as horizontal reference frame
tphpg = Use page as horizontal reference frame
tposnegx = Same as \\tposx but allows arbitrary negative values
tposnegy = Same as \\tposy but allows arbitrary negative values
tposx = Positions table N twips from left edge of horizontal reference frame
tposxc = Centers table within horizontal reference frame
tposxi = Positions table inside horizontal reference frame
tposxl = Positions table at left of horizontal reference frame
tposxo = Positions table outside horizontal reference frame
tposxr = Positions table at right of horizontal reference frame
tposy = Positions table N twips from top edge of vertical reference frame
tposyb = Positions table at bottom of vertical reference frame
tposyc = Centers table within vertical reference frame
tposyil = Positions table to be inline
tposyin = Positions table inside within vertical reference frame
tposyout = Positions table outside within vertical reference frame
tposyt = Positions table at top of vertical reference frame
tpvmrg = Positions table vertically relative to top margin
tpvpara = Positions table vertically relative to top left corner of next unframed paragraph in stream
tpvpg = Positions table vertically relative to top of page
tqc = Centered tab
tqdec = Decimal tab
tqr = Flush-right tab
transmf = Metafiles are considered transparent; don't blank area behind metafiles
trauth = With revision tracking enabled, this control word identifies author of changes to a table row's properties
trautofit = AutoFit
trbgbdiag = Backward diagonal pattern
trbgcross = Cross pattern
trbgdcross = Diagonal cross pattern
trbgdkbdiag = Dark backward diagonal pattern
trbgdkcross = Dark cross pattern
trbgdkdcross = Dark diagonal cross pattern
trbgdkfdiag = Dark forward diagonal pattern
trbgdkhor = Dark horizontal pattern
trbgdkvert = Dark vertical pattern
trbgfdiag = Forward diagonal pattern
trbghoriz = Horizontal pattern
trbgvert = Vertical pattern
trbrdrb = Table row border bottom
trbrdrh = Table row border horizontal (inside)
trbrdrl = Table row border left
trbrdrr = Table row border right
trbrdrt = Table row border top
trbrdrv = Table row border vertical (inside)
trcbpat = Background pattern color for table row shading
trcfpat = Foreground pattern color for table row shading
trdate = With revision tracking enabled, this control word identifies date on which a revision was made
trftswidth = Units for \\clwWidthN
trftswidtha = Units for \\clwWidthBN
trftswidthb = Units for \\clwWidthBN
trgaph = Half space between cells of a table row in twips
trhdr = Table row header
trkeep = Keep table row together
trkeepfollow = Keep row in same page as following row
trleft = Position in twips of leftmost edge of table with respect to left edge of its column
trowd = Sets table row defaults
trpaddb = Default bottom cell margin or padding for row
trpaddfb = Units for \\trpaddbN
trpaddfl = Units for \\trpaddlN
trpaddfr = Units for \\trpaddrN
trpaddft = Units for \\trpaddtN
trpaddl = Default left cell margin or padding for row
trpaddr = Default right cell margin or padding for row
trpaddt = Default top cell margin or padding for row
trpat = Pattern for table row shading
trqc = Centers a table row with respect to its containing column
trql = Left-justifies a table row with respect to its containing column
trqr = Right-justifies a table row with respect to its containing column
trrh = Height of a table row in twips
trshdng = Percentage shading for table row shading
trspdb = Default bottom cell spacing for row
trspdfb = Units for \\trspdbN
trspdfl = Units for \\trspdlN
trspdfr = Units for \\trspdrN
trspdft = Units for \\trspdtN
trspdl = Default left cell spacing for row
trspdr = Default right cell spacing for row
trspdt = Default top cell spacing for row
truncatefontheight = Round down to nearest font size instead of rounding up
truncex = Don't add leading (extra space) between rows of text
trwwidth = Preferred row width
trwwidtha = Width of invisible cell at end of row
trwwidthb = Width of invisible cell at beginning of row
ts = Designates table style, in same style as \\cs for placement and prefixes
tsbgbdiag = Cell shading pattern - backward diagonal (////)
tsbgcross = Cell shading pattern - cross
tsbgdcross = Cell shading pattern - diagonal cross
tsbgdkbdiag = Cell shading pattern - dark backward diagonal (////)
tsbgdkcross = Cell shading pattern - dark cross
tsbgdkdcross = Cell shading pattern - dark diagonal cross 
tsbgdkfdiag = Cell shading pattern - dark forward diagonal (\\\\\\\\)
tsbgdkhor = Cell shading pattern - dark horizontal
tsbgdkvert = Cell shading pattern - dark vertical
tsbgfdiag = Cell shading pattern - forward diagonal (\\\\\\\\)
tsbghoriz = Cell shading pattern - horizontal
tsbgvert = Cell shading pattern - vertical
tsbrdrb = Bottom border for cell
tsbrdrdgl = Diagonal (top left to bottom right) border for cell
tsbrdrdgr = Diagonal (bottom left to top right) border for cell
tsbrdrh = Horizontal (inside) border for cell
tsbrdrl = Left border for cell
tsbrdrr = Right border for cell
tsbrdrt = Top border for cell
tsbrdrv = Vertical (inside) border for cell
tscbandhorzeven = This cell is in even row band
tscbandhorzodd = This cell is in odd row band
tscbandsh = Count of rows in a row band
tscbandsv = Count of cells in a cell band
tscbandverteven = This cell is in even column band
tscbandvertodd = This cell is in odd column band
tscellcbpat = Background cell shading color
tscellcfpat = Foreground cell shading color
tscellpaddb = Bottom padding value
tscellpaddfb = Units for \\tscellpaddbN0
tscellpaddfl = Units for \\tscellpaddlN0
tscellpaddfr = Units for \\tscellpaddrN0
tscellpaddft = Units for \\tscellpaddtN0
tscellpaddl = Left padding value
tscellpaddr = Right padding value
tscellpaddt = Top padding value
tscellpct = Cell shading percentage - N is shading of a table cell in hundredths of a percent
tscellwidth = Currently emitted but has no effect
tscellwidthfts = Currently emitted but has no effect
tscfirstcol = This cell is in first column
tscfirstrow = This cell is in first row
tsclastcol = This cell is in last column
tsclastrow = This cell is in last row
tscnecell = NE cell
tscnwcell = This is NW cell in table (top left)
tscsecell = SE cell
tscswcell = SW cell
tsd = Sets default table style for this document
tsnowrap = No cell wrapping
tsrowd = Like \\trowd but for table style definitions
tsvertalb = Bottom vertical alignment of cell
tsvertalc = Center vertical alignment of cell
tsvertalt = Top vertical alignment of cell
twoinone = Text in group is displayed as two half-height lines within a line:
twoonone = Print two logical pages on one physical page
tx = Tab position in twips from left margin
txe Text = Text argument to be used instead of a page number
u = This keyword represents a single Unicode character that has no equivalent ANSI representation based on current ANSI code page
uc = This keyword represents number of bytes corresponding to a given \\uN Unicode character
ud = This is a destination that is represented in Unicode
ul = Continuous underline. \\ul0 turns off all underlining
ulc = Underline color
uld = Dotted underline
uldash = Dashed underline
uldashd = Dash-dotted underline
uldashdd = Dash-dot-dotted underline
uldb = Double underline
ulhair = Hairline underline
ulhwave = Heavy wave underline
ulldash = Long dashed underline
ulnone = Stops all underlining
ulth = Thick underline
ulthd = Thick dotted underline
ulthdash = Thick dashed underline
ulthdashd = Thick dash-dotted underline
ulthdashdd = Thick dash-dot-dotted underline
ulthldash = Thick long dashed underline
ululdbwave = Double wave underline
ulw = Word underline
ulwave = Wave underline
up = Superscript position in half-points (the default is 6)
upr = This keyword represents a destination with two embedded destinations, one represented using Unicode and other using ANSI
useltbaln = Don't forget last tab alignment
v = Hidden text
vern = Internal version number
version = Version number of document
vertalb = Text is bottom-aligned
vertalc = Text is centered vertically
vertalj = Text is justified vertically
vertalt = Text is top-aligned (the default)
vertdoc = Vertical rendering
vertsect = Vertical rendering
viewkind = An integer (0 through 5) that represents view mode of document.
viewnobound = Hide white space between pages
viewscale = Zoom level of document; N argument is a value representing a percentage (the default is 100)
viewzk = An integer (0 through 2) that represents zoom kind of document.
wbitmap = Source of picture is a Windows device-dependent bitmap
wbmbitspixel = Number of adjacent color bits on each plane needed to define a pixel
wbmplanes = Number of bitmap color planes (must equal 1)
wbmwidthbytes = Specifies number of bytes in each raster line
webhidden = Indicates that text in group is hidden in Word 2002 Web View and will not be emitted upon saving as Web page
widctlpar = Widow/orphan control is used for current paragraph
widowctrl = Enable widow and orphan control
windowcaption = Sets caption text for document window
wmetafile = Source of picture is a Windows metafile
wpjst = Do full justification like WordPerfect 6.x for Windows
wpsp = Set width of a space like WordPerfect 5.x
wptab = Advance to next tab stop like WordPerfect 6.x
wraptrsp = Wrap trailing spaces onto next line
wrppunct = Allow hanging punctuation in character grid
xef = Allows multiple indexes within same document
yr = Year
yts = Designates table style that was applied to row/cell
yxe = Pronunciation (or heading) for index entry, used in phonetic sorting
zwbo = Zero-width break opportunity
zwj = Zero-width joiner
zwnbo = Zero-width nonbreak opportunity
zwnj = Zero-width nonjoiner


clFitText = Fit text in cell, compressing each paragraph to width of cell.
clfittext = Fit text in cell, compressing each paragraph to width of cell.

clftsWidth = Units for \\clwwidth
clftswidth = Units for \\clwwidth

clNoWrap = Do not wrap text for cell.
clnowrap = Do not wrap text for cell.

clwWidth = Preferred cell width.
clwwidth = Preferred cell width.

tdfrmtxtBottom = Distance in twips, between bottom of table and surrounding text
tdfrmtxtbottom = Distance in twips, between bottom of table and surrounding text
tdfrmtxtLeft = Distance in twips, between left side of table and surrounding text
tdfrmtxtleft = Distance in twips, between left side of table and surrounding text
tdfrmtxtRight = Distance in twips, between right side of table and surrounding text
tdfrmtxtright = Distance in twips, between right side of table and surrounding text
tdfrmtxtTop = Distance in twips, between top of table and surrounding text
tdfrmtxttop = Distance in twips, between top of table and surrounding text

trftsWidthA = Units for \\clwWidthB
trftsWidthB = Units for \\clwWidthB
trftsWidth =  Units for \\clwWidth
trwWidthA = Width of invisible cell at end of row.
trwwidtha = Width of invisible cell at end of row.
trwWidthB = Width of invisible cell at beginning of row.
trwwidthb = Width of invisible cell at beginning of row.
trwWidth = Preferred row width.
trwwidth = Preferred row width.

sectspecifygenN = Indicates that text should snap to character grid.
sectspecifygenn = Indicates that text should snap to character grid.

applybrkrules = Use line breaking rules compatible with Thai text
ApplyBrkRules = Use line breaking rules compatible with Thai text


:endofperl

